factory

package
v1.2.13 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 11, 2025 License: MIT Imports: 14 Imported by: 2

Documentation

Overview

Package factory provides a factory for creating and managing broker services.

Package factory fornece uma fábrica para criar serviços Docker.

Index

Constants

const (
	EnginePostgres = prv.EnginePostgres
	EngineMongo    = prv.EngineMongo
	EngineRedis    = prv.EngineRedis
	EngineRabbit   = prv.EngineRabbit
)

Variables

This section is empty.

Functions

func GetMigrationFiles added in v1.2.12

func GetMigrationFiles() embed.FS

func Register added in v1.2.12

func Register(p Provider)

func SetMigrationFiles added in v1.2.12

func SetMigrationFiles(mf embed.FS)

func SetupDatabaseServices

func SetupDatabaseServices(ctx context.Context, d svc.IDockerService, config *DBConfigImpl) error

Types

type Capabilities added in v1.2.12

type Capabilities = prv.Capabilities

type CloudflaredOpts

type CloudflaredOpts struct {
	Mode        TunnelMode
	NetworkName string
	TargetDNS   string // quick: service DNS a expor
	TargetPort  int    // quick: porta HTTP do alvo
	Token       string // named: TUNNEL_TOKEN
}

func NewCloudflaredOpts

func NewCloudflaredOpts(mode TunnelMode, networkName, targetDNS string, targetPort int, token string) CloudflaredOpts

func (CloudflaredOpts) Start

type CryptoService

type CryptoService = sci.ICryptoService

func NewCryptoService

func NewCryptoService() CryptoService

type DBConfig

type DBConfig = svc.IDBConfig

type DBConfigImpl added in v1.2.12

type DBConfigImpl = svc.DBConfig

func NewDBConfigFromFile added in v1.2.12

func NewDBConfigFromFile(ctx context.Context, dbConfigFilePath string, autoMigrate bool, logger l.Logger, debug bool) (*DBConfigImpl, error)

func NewDBConfigWithArgs added in v1.2.12

func NewDBConfigWithArgs(ctx context.Context, dbName, dbConfigFilePath string, autoMigrate bool, logger l.Logger, debug bool) *DBConfigImpl

type DBService

type DBService = svc.DBService

func NewDatabaseService

func NewDatabaseService(ctx context.Context, config *DBConfigImpl, logger l.Logger) (DBService, error)

type DBServiceImpl added in v1.2.12

type DBServiceImpl = svc.DBServiceImpl

func NewDatabaseServiceImpl added in v1.2.12

func NewDatabaseServiceImpl(ctx context.Context, config *DBConfigImpl, logger l.Logger) (*DBServiceImpl, error)

type Database added in v1.2.12

type Database = it.Database

type DatabaseImpl added in v1.2.12

type DatabaseImpl = it.Database

type DirectDatabase added in v1.2.12

type DirectDatabase interface {
	Query(context.Context, string, ...interface{}) (any, error)
}

type DockerService added in v1.2.12

type DockerService = svc.DockerService

type DockerSrv

type DockerSrv = dkrs.IDockerService

func NewDockerService

func NewDockerService(config *dkrs.DBConfig, logger l.Logger) (DockerSrv, error)

type DockerStackProvider added in v1.2.12

type DockerStackProvider = dksk.Provider

func NewDockerStackProvider added in v1.2.12

func NewDockerStackProvider() *DockerStackProvider

type Endpoint added in v1.2.12

type Endpoint = prv.Endpoint

type Engine added in v1.2.12

type Engine = prv.Engine

type Environment added in v1.2.12

type Environment = ci.IEnvironment

type EnvironmentType added in v1.2.12

type EnvironmentType = it.Environment

func NewEnvironment added in v1.2.12

func NewEnvironment(configFile string, isConfidential bool, logger l.Logger) (*EnvironmentType, error)

type IDBConfig

type IDBConfig interface {
	svc.IDBConfig
}

type IDBService added in v1.2.12

type IDBService interface{ svc.DBService }

type IDockerService added in v1.2.12

type IDockerService = svc.IDockerService

type IJSONB added in v1.2.12

type IJSONB interface {
	ci.IJSONB
}

func NewJSONB added in v1.2.12

func NewJSONB() IJSONB

type IJSONBData added in v1.2.12

type IJSONBData interface{ ci.IJSONB }

type IReference added in v1.2.12

type IReference interface {
	ci.IReference
}

func NewReference added in v1.2.12

func NewReference(name string) IReference

type JSONB added in v1.2.12

type JSONB = ci.IJSONB

type JSONBData added in v1.2.12

type JSONBData = it.JSONBData

func NewJSONBData added in v1.2.12

func NewJSONBData() JSONBData

type JSONBImpl added in v1.2.12

type JSONBImpl = it.JSONBImpl

type JWT added in v1.2.12

type JWT = it.JWT

type JWTImpl added in v1.2.12

type JWTImpl = it.JWT

func NewJWT added in v1.2.12

func NewJWT() *JWTImpl

type KeyringService

type KeyringService = sci.IKeyringService

func NewKeyringService

func NewKeyringService(keyringServiceName, keyringServicePath string) KeyringService

type Messagery added in v1.2.12

type Messagery = it.Messagery

type MigrationManager added in v1.2.12

type MigrationManager = dksk.MigrationManager

func CreateMigrationManager added in v1.2.12

func CreateMigrationManager(dsn string, logger l.Logger) *MigrationManager

func NewMigrationManager added in v1.2.12

func NewMigrationManager(dsn string, logger l.Logger) *MigrationManager

type MigrationResult added in v1.2.12

type MigrationResult = dksk.MigrationResult

type MongoDB added in v1.2.12

type MongoDB = it.MongoDB

type MongoDBConfig added in v1.2.12

type MongoDBConfig = it.MongoDB

type MySQLConfig added in v1.2.12

type MySQLConfig = it.Database

type PostgresConfig added in v1.2.12

type PostgresConfig = it.Database

type Provider added in v1.2.12

type Provider = prv.Provider

func All added in v1.2.12

func All() []Provider

func Get added in v1.2.12

func Get(name string) (Provider, bool)

type RabbitMQ added in v1.2.12

type RabbitMQ = it.RabbitMQ

type RabbitMQConfig added in v1.2.12

type RabbitMQConfig = it.RabbitMQ

type Redis added in v1.2.12

type Redis = it.Redis

type RedisConfig added in v1.2.12

type RedisConfig = it.Redis

type Reference added in v1.2.12

type Reference = it.Reference

type ReferenceImpl added in v1.2.12

type ReferenceImpl = it.Reference

type Rows added in v1.2.12

type Rows interface {
	Next() bool
	Scan(dest ...interface{}) error
	Close() error
	Err() error
}

type SQLStatement added in v1.2.12

type SQLStatement = dksk.SQLStatement

type SQLiteConfig added in v1.2.12

type SQLiteConfig = it.Database

type ServiceRef added in v1.2.12

type ServiceRef = prv.ServiceRef

type StartSpec added in v1.2.12

type StartSpec = prv.StartSpec

type StatementError added in v1.2.12

type StatementError = dksk.StatementError

type TunnelHandle

type TunnelHandle interface {
	Stop(ctx context.Context) error
}

type TunnelMode

type TunnelMode string
const (
	TunnelQuick TunnelMode = "quick" // HTTP efêmero (URL dinâmica)
	TunnelNamed TunnelMode = "named" // HTTP+TCP fixo (Access)
)

Directories

Path Synopsis
Package models provides factory functions for OAuth models
Package models provides factory functions for OAuth models
mcp
Package mcp provides the LLM model and its methods for text generation and manipulation
Package mcp provides the LLM model and its methods for text generation and manipulation

Jump to