Documentation
¶
Overview ¶
Package factory provides a factory for creating and managing broker services.
Package factory fornece uma fábrica para criar serviços Docker.
Index ¶
- Constants
- func GetMigrationFiles() embed.FS
- func Register(p Provider)
- func SetMigrationFiles(mf embed.FS)
- func SetupDatabaseServices(ctx context.Context, d svc.IDockerService, config *DBConfigImpl) error
- type Capabilities
- type CloudflaredOpts
- type CryptoService
- type DBConfig
- type DBConfigImpl
- type DBService
- type DBServiceImpl
- type Database
- type DatabaseImpl
- type DirectDatabase
- type DockerService
- type DockerSrv
- type DockerStackProvider
- type Endpoint
- type Engine
- type Environment
- type EnvironmentType
- type IDBConfig
- type IDBService
- type IDockerService
- type IJSONB
- type IJSONBData
- type IReference
- type JSONB
- type JSONBData
- type JSONBImpl
- type JWT
- type JWTImpl
- type KeyringService
- type Messagery
- type MigrationManager
- type MigrationResult
- type MongoDB
- type MongoDBConfig
- type MySQLConfig
- type PostgresConfig
- type Provider
- type RabbitMQ
- type RabbitMQConfig
- type Redis
- type RedisConfig
- type Reference
- type ReferenceImpl
- type Rows
- type SQLStatement
- type SQLiteConfig
- type ServiceRef
- type StartSpec
- type StatementError
- type TunnelHandle
- type TunnelMode
Constants ¶
const ( EnginePostgres = prv.EnginePostgres EngineMongo = prv.EngineMongo EngineRedis = prv.EngineRedis EngineRabbit = prv.EngineRabbit )
Variables ¶
This section is empty.
Functions ¶
func GetMigrationFiles ¶ added in v1.2.12
func SetMigrationFiles ¶ added in v1.2.12
func SetupDatabaseServices ¶
func SetupDatabaseServices(ctx context.Context, d svc.IDockerService, config *DBConfigImpl) error
Types ¶
type Capabilities ¶ added in v1.2.12
type Capabilities = prv.Capabilities
type CloudflaredOpts ¶
type CloudflaredOpts struct {
Mode TunnelMode
NetworkName string
TargetDNS string // quick: service DNS a expor
TargetPort int // quick: porta HTTP do alvo
Token string // named: TUNNEL_TOKEN
}
func NewCloudflaredOpts ¶
func NewCloudflaredOpts(mode TunnelMode, networkName, targetDNS string, targetPort int, token string) CloudflaredOpts
func (CloudflaredOpts) Start ¶
func (o CloudflaredOpts) Start(ctx context.Context, cli *client.Client) (TunnelHandle, string, error)
type CryptoService ¶
type CryptoService = sci.ICryptoService
func NewCryptoService ¶
func NewCryptoService() CryptoService
type DBConfigImpl ¶ added in v1.2.12
func NewDBConfigFromFile ¶ added in v1.2.12
func NewDBConfigWithArgs ¶ added in v1.2.12
type DBService ¶
func NewDatabaseService ¶
type DBServiceImpl ¶ added in v1.2.12
type DBServiceImpl = svc.DBServiceImpl
func NewDatabaseServiceImpl ¶ added in v1.2.12
func NewDatabaseServiceImpl(ctx context.Context, config *DBConfigImpl, logger l.Logger) (*DBServiceImpl, error)
type DatabaseImpl ¶ added in v1.2.12
type DirectDatabase ¶ added in v1.2.12
type DockerService ¶ added in v1.2.12
type DockerService = svc.DockerService
type DockerSrv ¶
type DockerSrv = dkrs.IDockerService
type DockerStackProvider ¶ added in v1.2.12
func NewDockerStackProvider ¶ added in v1.2.12
func NewDockerStackProvider() *DockerStackProvider
type Environment ¶ added in v1.2.12
type Environment = ci.IEnvironment
type EnvironmentType ¶ added in v1.2.12
type EnvironmentType = it.Environment
func NewEnvironment ¶ added in v1.2.12
type IDBService ¶ added in v1.2.12
type IDockerService ¶ added in v1.2.12
type IDockerService = svc.IDockerService
type IJSONBData ¶ added in v1.2.12
type IReference ¶ added in v1.2.12
type IReference interface {
ci.IReference
}
func NewReference ¶ added in v1.2.12
func NewReference(name string) IReference
type JSONBData ¶ added in v1.2.12
func NewJSONBData ¶ added in v1.2.12
func NewJSONBData() JSONBData
type KeyringService ¶
type KeyringService = sci.IKeyringService
func NewKeyringService ¶
func NewKeyringService(keyringServiceName, keyringServicePath string) KeyringService
type MigrationManager ¶ added in v1.2.12
type MigrationManager = dksk.MigrationManager
func CreateMigrationManager ¶ added in v1.2.12
func CreateMigrationManager(dsn string, logger l.Logger) *MigrationManager
func NewMigrationManager ¶ added in v1.2.12
func NewMigrationManager(dsn string, logger l.Logger) *MigrationManager
type MigrationResult ¶ added in v1.2.12
type MigrationResult = dksk.MigrationResult
type MongoDBConfig ¶ added in v1.2.12
type MySQLConfig ¶ added in v1.2.12
type PostgresConfig ¶ added in v1.2.12
type RabbitMQConfig ¶ added in v1.2.12
type RedisConfig ¶ added in v1.2.12
type ReferenceImpl ¶ added in v1.2.12
type SQLStatement ¶ added in v1.2.12
type SQLStatement = dksk.SQLStatement
type SQLiteConfig ¶ added in v1.2.12
type ServiceRef ¶ added in v1.2.12
type ServiceRef = prv.ServiceRef
type StatementError ¶ added in v1.2.12
type StatementError = dksk.StatementError
type TunnelHandle ¶
type TunnelMode ¶
type TunnelMode string
const ( TunnelQuick TunnelMode = "quick" // HTTP efêmero (URL dinâmica) TunnelNamed TunnelMode = "named" // HTTP+TCP fixo (Access) )
Directories
¶
| Path | Synopsis |
|---|---|
|
Package models provides factory functions for OAuth models
|
Package models provides factory functions for OAuth models |
|
mcp
Package mcp provides the LLM model and its methods for text generation and manipulation
|
Package mcp provides the LLM model and its methods for text generation and manipulation |
Click to show internal directories.
Click to hide internal directories.